PROMOTIONS = {
    'msc1': 'msc4',
    'msc2': 'msc5',
    'premsc': 'msc3',
    'wac1': 'wac1',
    'wac2': 'wac2',
    'tek1': 'tek1',
    'tek2': 'tek2',
    'tek3': 'tek3',
}

courses = 'course[]=Code-And-Go&course[]=Dev-And-Go&course[]=msc&course[]=premsc&course[]=webacademie&course[]=other'

INTRA_LINK = r'intra\.epitech\.eu'
